
Python library *goma*
---------------------

.. image:: https://img.shields.io/codeship/af416f50-ba89-0137-8179-0660bd8c08b8/master.svg
   :target: https://codeship.com//projects/364825
   :alt: CodeShip

.. image:: https://travis-ci.org/sonntagsgesicht/goma.svg?branch=master
   :target: https://travis-ci.org/sonntagsgesicht/goma
   :alt: Travis ci

.. image:: https://img.shields.io/readthedocs/goma
   :target: http://goma.readthedocs.io
   :alt: Read the Docs

.. image:: https://img.shields.io/codefactor/grade/github/sonntagsgesicht/goma/master
   :target: https://www.codefactor.io/repository/github/sonntagsgesicht/goma
   :alt: CodeFactor Grade

.. image:: https://img.shields.io/codeclimate/maintainability/sonntagsgesicht/goma
   :target: https://codeclimate.com/github/sonntagsgesicht/goma/maintainability
   :alt: Code Climate maintainability

.. image:: https://img.shields.io/codecov/c/github/sonntagsgesicht/goma
   :target: https://codecov.io/gh/sonntagsgesicht/goma
   :alt: Codecov

.. image:: https://img.shields.io/lgtm/grade/python/g/sonntagsgesicht/goma.svg
   :target: https://lgtm.com/projects/g/sonntagsgesicht/goma/context:python/
   :alt: lgtm grade

.. image:: https://img.shields.io/lgtm/alerts/g/sonntagsgesicht/goma.svg
   :target: https://lgtm.com/projects/g/sonntagsgesicht/goma/alerts/
   :alt: total lgtm alerts

.. image:: https://img.shields.io/github/license/sonntagsgesicht/goma
   :target: https://github.com/sonntagsgesicht/goma/raw/master/LICENSE
   :alt: GitHub

.. image:: https://img.shields.io/github/release/sonntagsgesicht/goma?label=github
   :target: https://github.com/sonntagsgesicht/goma/releases
   :alt: GitHub release

.. image:: https://img.shields.io/pypi/v/goma
   :target: https://pypi.org/project/goma/
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/goma
   :target: https://pypi.org/project/goma/
   :alt: PyPI - Python Version

.. image:: https://img.shields.io/pypi/dm/goma
   :target: https://pypi.org/project/goma/
   :alt: PyPI Downloads

goma - generic object mapping algorithm

A library for easy implementing complex mappings procedures.


Development Version
-------------------

The latest development version can be installed directly from GitHub:

.. code-block:: bash

    $ pip install --upgrade git+https://github.com/sonntagsgesicht/goma.git


Contributions
-------------

.. _issues: https://github.com/sonntagsgesicht/goma/issues
.. __: https://github.com/sonntagsgesicht/goma/pulls

Issues_ and `Pull Requests`__ are always welcome.


License
-------

.. __: https://github.com/sonntagsgesicht/goma/raw/master/LICENSE

Code and documentation are available according to the Apache Software License (see LICENSE__).


